# FitConnect SDK User Guide

## Introduction

The SDK supports a high-level support as well as a low-level support for the
FitConnect API and a fluent API.

## All in one

For not having to deal with the low-level API, the SDK provides a high-level support.

### Sender

```mermaid
flowchart TD
    client([Create a new FitConnect client])
    send.submission[Create new Submission]
    send.send[Send the submission]
    send.return[\Return the result/]
    
    client-->send.submission-->send.send-->send.return
    
    
    subscribe.request[Request submissions]
    
    client-->subscribe.request-->ToBeDefined
```

Simplified call:

```csharp
bool SendSubmission(Submission submission){
    var client = new Client(...);
    return client.SendSubmissionAsync(submission);
}
```

### Subscriber

### Example

Visit [All in one](./all_in_one.md) to see the code.

## Fluent Api

### Sender

```mermaid
stateDiagram
    [*]-->Authenticate
    Authenticate-->CreateSubmission
    CreateSubmission-->UploadAttachments
    UploadAttachments-->SendSubmission
    SendSubmission-->[*]
```

### Subscriber

```mermaid
stateDiagram
    [*]-->Authenticate
     Authenticate-->GetSubmissions
    GetSubmissions-->[*]
    
    Authenticate-->GetSubmission
    GetSubmission-->GetAttachments
    GetAttachments-->DecryptAttachments
    DecryptAttachments-->DecryptData
    DecryptData-->DecryptMetadata
    DecryptMetadata-->[*]
```

#### Receiving list of submissions

#### Receiving specific submission

[Fluent Api Example](./fluent_api.md)

## Detailed calls

[Detailed calls](./detailed_calls.md)

