using FitConnect.Models;
using FitConnect.Models.v1.Api;
using Data = FitConnect.Models.Data;

namespace FitConnect.Interfaces.Subscriber;

public interface ISubscriberWithSubmission {
    public Submission Submission { get; }

    /// <summary>
    /// Returns the data (Fachdaten) of the submission
    /// </summary>
    /// <returns></returns>
    public string? GetDataJson() => Submission.Data;

    /// <summary>
    ///     Loads the <see cref="Attachment" />s for the given <see cref="Submission" />.
    /// </summary>
    /// <returns>Enumerable of the attachments</returns>
    public IEnumerable<Attachment> GetAttachments();

    /// <summary>
    ///     Accept submission and delete it from the server
    /// </summary>
    public void AcceptSubmission();

    /// <summary>
    /// Rejects the submission
    /// </summary>
    /// <param name="problems">Reasons for the rejection</param>
    public void RejectSubmission(params Problems[] problems);

    /// <summary>
    /// Set submission state to forwarded
    /// </summary>
    public void ForwardSubmission();

    /// <summary>
    /// Set submission state
    /// </summary>
    /// <param name="status">state the submission has to be set to</param>
    public void CompleteSubmission(FinishSubmissionStatus status);
}
