using FitConnect.Services.Models.v1.Submission;

namespace FitConnect.Services.Interfaces;

public interface ISubmissionService : IRestCallService {
    /// <summary>
    ///     <para>@PostMapping("/submissions")</para>
    /// </summary>
    /// <param name="submissionDto">RequestBody</param>
    /// <returns></returns>
        SubmissionCreatedDto CreateSubmission(CreateSubmissionDto submissionDto);

    /// <summary>
    ///     <para>
    ///         @PutMapping(value = "/submissions/{submissionId}/attachments/{attachmentId}", consumes =
    ///         "application/jose")
    ///     </para>
    /// </summary>
    /// <param name="submissionId">PathVariable</param>
    /// <param name="attachmentId">PathVariable</param>
    /// <param name="encryptedAttachmentContent">RequestBody</param>
    /// <returns></returns>
        bool AddSubmissionAttachment(string submissionId, string attachmentId,
        string encryptedAttachmentContent);

    /// <summary>
    ///     <para>@PutMapping(value = "/submissions/{submissionId}", consumes = "application/json") </para>
    /// </summary>
    /// <param name="submissionId">PathVariable</param>
    /// <param name="submitSubmission">RequestBody</param>
    /// <returns></returns>
        Task<SubmissionReducedDto?> SubmitSubmission(string submissionId,
        SubmitSubmissionDto submitSubmission);

    /// <summary>
    ///     <para>@GetMapping("/submissions")</para>
    /// </summary>
    /// <param name="destinationId">RequestParam</param>
    /// <param name="offset">RequestParam</param>
    /// <param name="limit">RequestParam</param>
    /// <returns></returns>
        Task<SubmissionsForPickupDto> ListSubmissions(string? destinationId, int offset,
        int limit);

    /// <summary>
    ///     <para>@GetMapping("/submissions/{submissionId}")</para>
    /// </summary>
    /// <param name="submissionId">PathVariable</param>
    /// <returns></returns>
        SubmissionDto GetSubmission(string submissionId);

    /// <summary>
    ///     <para>
    ///         @GetMapping(value = "/submissions/{submissionId}/attachments/{attachmentId}", produces =
    ///         "application/jose")
    ///     </para>
    /// </summary>
    /// <param name="submissionId">PathVariable</param>
    /// <param name="attachmentId">PathVariable</param>
    /// <returns></returns>
        string GetAttachment(string submissionId, string attachmentId);

    /// <summary>
    ///     Receiving the encryption key from the submission api
    /// </summary>
    /// <param name="keyId"></param>
    /// <returns></returns>
    string GetKey(string keyId);


    /// <summary>
    ///     Uploads an attachment to the submission api
    /// </summary>
    /// <param name="submissionId"></param>
    /// <param name="attachmentId"></param>
    /// <param name="content"></param>
    void UploadAttachment(string submissionId, string attachmentId, string content) {
        AddSubmissionAttachment(submissionId, attachmentId, content);
    }

    /// <summary>
    ///     Retrieves the events of a submission
    /// </summary>
    /// <param name="caseId"></param>
    /// <returns></returns>
    Task<List<string>> GetStatusForSubmissionAsync(string caseId);
}

public interface ICasesService {
    public string FinishSubmission(string caseId, string token);
}
