using FitConnect.Models;
using FitConnect.Services.Interfaces;
using FitConnect.Services.Models.v1.Routes;
using Microsoft.Extensions.Logging;
using Route = FitConnect.Services.Models.v1.Routes.Route;

namespace FitConnect.Services;

public class RouteService : RestCallService, IRouteService {


    public RouteService(string baseUrl, string version = "v1",
        ILogger? logger = null) : base($"{baseUrl}/{version}", logger) {
  
    }

    /// <summary>
    ///     Returns the destination id for the given intent.
    /// </summary>
    /// <param name="leikaKey"></param>
    /// <param name="ags"></param>
    /// <param name="ars"></param>
    /// <param name="areaId"></param>
    /// <returns></returns>
    public async Task<List<Route>> GetDestinationIdAsync(string leikaKey,
        string? ags, string? ars,
        string? areaId) {
        if (ars == null && ags == null && areaId == null)
            throw new ArgumentException("Either ars, ags or areaId must be specified.");

        var result = await RestCall<RoutesListDto>($"/routes?leikaKey={leikaKey}" +
                                                   (ags != null ? $"&ags={ags}" : "") +
                                                   (ars != null ? $"&ars={ars}" : "") +
                                                   (areaId != null ? $"&areaId={areaId}" : ""),
            HttpMethod.Get);

        return result?.Routes?.ToList() ?? new List<Route>();
    }

    public async Task<AreaList?> GetAreas(string filter, int offset = 0, int limit = 100) {
        var result = await RestCall<AreaList>(
            $"/areas?areaSearchexpression={filter}&offset={offset}&limit={limit}",
            HttpMethod.Get);

        return result;
    }
}
